import { computed } from 'nativescript-vue';
import { useMediaQuery } from '../useMediaQuery';
/**
 * Reactive screen breakpoints.
 *
 * @param breakpoints
 */
export function useBreakpoints(breakpoints) {
    function getValue(k, d) {
        let v = breakpoints[k];
        return v;
    }
    const greaterOrEqual = (k) => {
        return useMediaQuery(`(min-width: ${getValue(k)})`);
    };
    const shortcutMethods = Object.keys(breakpoints).reduce((shortcuts, k) => {
        Object.defineProperty(shortcuts, k, {
            get: () => greaterOrEqual(k),
            enumerable: true,
            configurable: true,
        });
        return shortcuts;
    }, {});
    return Object.assign(shortcutMethods, {
        greater(k) {
            return useMediaQuery(`(min-width: ${getValue(k, 0.1)})`);
        },
        greaterOrEqual,
        smaller(k) {
            return useMediaQuery(`(max-width: ${getValue(k, -0.1)})`);
        },
        smallerOrEqual(k) {
            return useMediaQuery(`(max-width: ${getValue(k)})`);
        },
        between(a, b) {
            return useMediaQuery(`(min-width: ${getValue(a)}) and (max-width: ${getValue(b, -0.1)})`);
        },
        isGreater(k) {
            return useMediaQuery(`(min-width: ${getValue(k, 0.1)})`);
        },
        isGreaterOrEqual(k) {
            return useMediaQuery(`(min-width: ${getValue(k)})`);
        },
        isSmaller(k) {
            return useMediaQuery(`(max-width: ${getValue(k, -0.1)})`);
        },
        isSmallerOrEqual(k) {
            return useMediaQuery(`(max-width: ${getValue(k)})`);
        },
        isInBetween(a, b) {
            return useMediaQuery(`(min-width: ${getValue(a)}) and (max-width: ${getValue(b, -0.1)})`);
        },
        current() {
            const points = Object.keys(breakpoints).map((i) => [i, greaterOrEqual(i)]);
            return computed(() => {
                return points.filter(([, v]) => v.value).map(([k]) => k);
            });
        },
    });
}
//# sourceMappingURL=index.js.map